@@ -25,6 +25,8 @@ def cache(file_name:str, max_age=30, dir=gettempdir()):
     def decorator(func):
         @wraps(func)
         def wrapper(*args, **kwargs):
+            if not Path(dir).is_absolute():
+                dir = Path(gettempdir(), dir)
             cache_file = Path(dir, file_name)
             if cache_file.exists() and file_age(cache_file) < max_age and cache_file.stat().st_size != 0:
                 with open(cache_file, 'r', encoding='utf-8') as f:
